==> boru-ocr-1.0.3-292134.tar: src/OcrEngine.php <==
<?php

namespace boru\ocr;

use boru\ocr\Agent\AgentOptions;
use boru\ocr\Agent\AiOcrOrchestrator;
use boru\ocr\Pipeline\OcrPipeline;
use boru\ocr\Pipeline\OcrPipelineResultBundle;
use boru\ocr\Pipeline\OcrResult;
use boru\ocr\Format\FrameFormatter;

class OcrEngine
{
    /** @var string */
    protected $sourceFile;

    /** @var string|null */
    protected $imageDir;

    /** @var array */
    protected $tesseractOptions = [
        'lang' => 'eng',
        // good defaults; adjust as needed
        'config' => [
            'preserve_interword_spaces' => '1',
        ],
    ];

    /** @var array */
    protected $providerOptions = [];

    /** @var array */
    protected $layoutOptions = [
        'minConf' => 0,
        'multiColumn' => true,
    ];

    /** @var callable|null */
    protected $logger;

    /** @var string */
    protected $tesseractBinary = 'tesseract';


    protected $useAI = false;
    protected $userPlanner = false;
    protected $useTableInterpreter = false;
    protected $plannerAgentOptions = null;
    protected $tableInterpreterOptions = null;
    protected $finalAgentOptions = null;

    /**
     * @param string $sourceFile
     */
    public function __construct($sourceFile)
    {
        $this->sourceFile = (string)$sourceFile;
    }

    /**
     * Named constructor.
     * @param string $sourceFile
     * @return self
     */
    public static function forFile($sourceFile)
    {
        return new self($sourceFile);
    }

    /**
     * @param string $dir
     * @return $this
     */
    public function withImageDir($dir)
    {
        $this->imageDir = (string)$dir;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withTesseractOptions(array $opts)
    {
        $this->tesseractOptions = $opts;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withProviderOptions(array $opts)
    {
        $this->providerOptions = $opts;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withLayoutOptions(array $opts)
    {
        $this->layoutOptions = $opts;
        return $this;
    }

    /**
     * @param callable $logger function(string $msg):void
     * @return $this
     */
    public function withLogger($logger)
    {
        $this->logger = $logger;
        return $this;
    }

    /**
     * @param string $binary
     * @return $this
     */
    public function withTesseractBinary($binary)
    {
        $this->tesseractBinary = (string)$binary;
        return $this;
    }

    /**
     * Enable AI.. optionally set custom agent options
     * @param AgentOptions|bool $useAI
     * @return $this
     */
    public function withAI($useAI=true)
    {
        if($useAI instanceof AgentOptions){
            $this->finalAgentOptions = $useAI;
            $this->useAI = true;
            return $this;
        }
        $this->useAI = $useAI;
        return $this;
    }

    /**
     * Enable AI Planner.. optionally set custom agent options
     * @param AgentOptions|bool $usePlanner
     * @return $this
     */
    public function withPlanner($usePlanner=true)
    {
        if($usePlanner instanceof AgentOptions){
            $this->plannerAgentOptions = $usePlanner;
            $this->userPlanner = true;
            return $this;
        }
        $this->userPlanner = $usePlanner;
        return $this;
    }

    /**
     * Enable AI Table Interpreter.. optionally set custom agent options
     * @param AgentOptions|bool $useTableInterpreter
     * @return $this
     */
    public function withTableInterpreter($useTableInterpreter=true)
    {
        if($useTableInterpreter instanceof AgentOptions){
            $this->tableInterpreterOptions = $useTableInterpreter;
            $this->useTableInterpreter = true;
            return $this;
        }
        $this->useTableInterpreter = $useTableInterpreter;
        return $this;
    }

    /**
     * Run the deterministic pipeline (no AI yet).
     *
     * Returns an OcrEngineResult wrapper with conveniences for callers.
     *
     * @return OcrEngineResult
     * @throws \Exception
     */
    public function run()
    {
        if(!$this->imageDir){
            $this->imageDir = sys_get_temp_dir().'/ocr_'.uniqid();
            if (!is_dir($this->imageDir)) {
               @mkdir($this->imageDir, 0777, true);
            }
        }
        $pipeline = new OcrPipeline(array(
            'logger' => $this->logger,
            'tesseractBinary' => $this->tesseractBinary,
            'tesseractOptions' => $this->tesseractOptions,
            'providerOptions' => $this->providerOptions,
            'layoutOptions' => $this->layoutOptions,
            'imageDir' => $this->imageDir,
        ));

        /** @var OcrPipelineResultBundle $bundle */
        $bundle = $pipeline->run($this->sourceFile);
        $result = new OcrEngineResult($bundle->result, $bundle->evidence);
        if($this->useAI) {
            if(!$this->finalAgentOptions){
                $this->finalAgentOptions = $this->defaultAgentOptions();
            }
            if(!$this->plannerAgentOptions){
                $this->plannerAgentOptions = $this->defaultAgentOptions();
            }
            if(!$this->tableInterpreterOptions){
                $this->tableInterpreterOptions = $this->defaultAgentOptions();
            }
            $orc = new AiOcrOrchestrator([
                "usePlanner" => $this->userPlanner,
                "useTableInterpreter" => $this->useTableInterpreter,
                "tableInterpreterOptions" => $this->tableInterpreterOptions,
                "plannerAgentOptions" => $this->plannerAgentOptions,
                "finalAgentOptions" => $this->finalAgentOptions,
            ], $this->logger);

            $final = $orc->run($this->sourceFile, $result);
            $result->setFinalText($final);
        }
        return $result;
    }

    private function defaultAgentOptions(){
        return new AgentOptions([
            'logger' => $this->logger,
            "model" => "gpt-4.1",
        ]);
    }
}

==> boru-ocr-1.0.4-1b1130.tar: src/OcrEngine.php <==
<?php

namespace boru\ocr;

use boru\ocr\Agent\AiOptions;
use boru\ocr\Agent\AgentOptions;
use boru\ocr\Agent\AiOcrOrchestrator;
use boru\ocr\OcrEngineResult;
use boru\ocr\Pipeline\OcrPipeline;
use boru\ocr\Pipeline\OcrPipelineResultBundle;


class OcrEngine
{
    /** @var string */
    protected $sourceFile;

    /** @var string|null */
    protected $imageDir;

    /** @var array */
    protected $tesseractOptions = [
        'lang' => 'eng',
        // good defaults; adjust as needed
        'config' => [
            'preserve_interword_spaces' => '1',
        ],
    ];

    /** @var array */
    protected $providerOptions = [];

    /** @var array */
    protected $layoutOptions = [
        'minConf' => 0,
        'multiColumn' => true,
        
    ];

    /** @var callable|null */
    protected $logger;

    /** @var string */
    protected $tesseractBinary = 'tesseract';


    protected $useAI = false;
    protected $userPlanner = false;
    protected $useTableInterpreter = false;
    protected $plannerAgentOptions = null;
    protected $tableInterpreterOptions = null;
    protected $finalAgentOptions = null;

    /** @var AiOptions|null */
    protected $aiOptions = null;

    /**
     * @param string $sourceFile
     */
    public function __construct($sourceFile)
    {
        $this->sourceFile = (string)$sourceFile;
    }

    /**
     * Named constructor.
     * @param string $sourceFile
     * @return self
     */
    public static function forFile($sourceFile)
    {
        return new self($sourceFile);
    }

    /**
     * @param string $dir
     * @return $this
     */
    public function withImageDir($dir)
    {
        $this->imageDir = (string)$dir;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withTesseractOptions(array $opts)
    {
        $this->tesseractOptions = $opts;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withProviderOptions(array $opts)
    {
        $this->providerOptions = $opts;
        return $this;
    }

    /**
     * @param array $opts
     * @return $this
     */
    public function withLayoutOptions(array $opts)
    {
        $this->layoutOptions = $opts;
        return $this;
    }

    /**
     * @param callable $logger function(string $msg):void
     * @return $this
     */
    public function withLogger($logger)
    {
        $this->logger = $logger;
        return $this;
    }

    /**
     * @param string $binary
     * @return $this
     */
    public function withTesseractBinary($binary)
    {
        $this->tesseractBinary = (string)$binary;
        return $this;
    }

    /**
     * Enable AI.. optionally set custom agent options
     * @param AgentOptions|bool $useAI
     * @return $this
     */
    public function withAI($useAI=true)
    {
        if($useAI instanceof AgentOptions){
            $this->finalAgentOptions = $useAI;
            $this->useAI = true;
            return $this;
        }
        if($useAI instanceof AiOptions){
            $this->aiOptions = $useAI;
            $this->useAI = true;
            return $this;
        } elseif(is_array($useAI)) {
            $this->aiOptions = AiOptions::fromArray($useAI);
            $this->useAI = true;
            return $this;
        }
        $this->useAI = $useAI;
        return $this;
    }

    /**
     * Enable AI Planner.. optionally set custom agent options
     * @param AgentOptions|bool $usePlanner
     * @return $this
     */
    public function withPlanner($usePlanner=true)
    {
        if($usePlanner instanceof AgentOptions){
            $this->plannerAgentOptions = $usePlanner;
            $this->userPlanner = true;
            return $this;
        }
        $this->userPlanner = $usePlanner;
        return $this;
    }

    /**
     * Enable AI Table Interpreter.. optionally set custom agent options
     * @param AgentOptions|bool $useTableInterpreter
     * @return $this
     */
    public function withTableInterpreter($useTableInterpreter=true)
    {
        if($useTableInterpreter instanceof AgentOptions){
            $this->tableInterpreterOptions = $useTableInterpreter;
            $this->useTableInterpreter = true;
            return $this;
        }
        $this->useTableInterpreter = $useTableInterpreter;
        return $this;
    }

    /**
     * Run the deterministic pipeline (no AI yet).
     *
     * Returns an OcrEngineResult wrapper with conveniences for callers.
     *
     * @return OcrEngineResult
     * @throws \Exception
     */
    public function run()
    {
        if(!$this->imageDir){
            $this->imageDir = sys_get_temp_dir().'/ocr_'.uniqid();
            if (!is_dir($this->imageDir)) {
               @mkdir($this->imageDir, 0777, true);
            }
        }
        $pipeline = new OcrPipeline(array(
            'logger' => $this->logger,
            'tesseractBinary' => $this->tesseractBinary,
            'tesseractOptions' => $this->tesseractOptions,
            'providerOptions' => $this->providerOptions,
            'layoutOptions' => $this->layoutOptions,
            'imageDir' => $this->imageDir,
        ));

        /** @var OcrPipelineResultBundle $bundle */
        $bundle = $pipeline->run($this->sourceFile);
        $result = new OcrEngineResult($bundle->result, $bundle->evidence);
        if($this->useAI) {
            if(!$this->finalAgentOptions){
                $this->finalAgentOptions = $this->defaultAgentOptions();
            }
            if(!$this->plannerAgentOptions){
                $this->plannerAgentOptions = $this->defaultAgentOptions();
            }
            if(!$this->tableInterpreterOptions){
                $this->tableInterpreterOptions = $this->defaultAgentOptions();
            }
            if(!$this->aiOptions){
                $this->aiOptions = AiOptions::fromArray([
                    "usePlanner" => $this->userPlanner,
                    "useTableInterpreter" => $this->useTableInterpreter,
                    "tableInterpreterOptions" => $this->tableInterpreterOptions,
                    "plannerAgentOptions" => $this->plannerAgentOptions,
                    "finalAgentOptions" => $this->finalAgentOptions,
                ]);
            }
            $orc = new AiOcrOrchestrator($this->aiOptions, $this->logger);

            $final = $orc->run($this->sourceFile, $result);
            $result->setFinalText($final);
        }
        return $result;
    }

    private function defaultAgentOptions(){
        return new AgentOptions([
            'logger' => $this->logger,
            "model" => "gpt-4.1",
        ]);
    }
}
